@@ -121,7 +121,7 @@ sub handle {
                                     };
                                     if ($@) {
                                         $response->code(HTTP_INTERNAL_SERVER_ERROR);
-                                        $self->{logger}->warn('JSON encode error: ', $@);
+                                        Lim::WARN and $self->{logger}->warn('JSON encode error: ', $@);
                                     }
                                     else {
                                         $response->header(
@@ -141,7 +141,7 @@ sub handle {
                                     };
                                     if ($@) {
                                         $response->code(HTTP_INTERNAL_SERVER_ERROR);
-                                        $self->{logger}->warn('JSON encode error: ', $@);
+                                        Lim::WARN and $self->{logger}->warn('JSON encode error: ', $@);
                                     }
                                     else {
                                         $response->header(
@@ -206,7 +206,7 @@ sub handle {
                 };
                 if ($@) {
                     $response->code(HTTP_INTERNAL_SERVER_ERROR);
-                    $self->{logger}->warn('JSON encode error: ', $@);
+                    Lim::WARN and $self->{logger}->warn('JSON encode error: ', $@);
                 }
             }
             elsif (!$response->code) {
